/*
 * SPDX-License-Identifier: BSD-2-Clause
 * SPDX-FileCopyrightText: 2026 Arjen Hiemstra <ahiemstra@heimr.nl>
 */

/*
 * This is a workaround for missing media-query support in the CSS parser.
 * Instead of media queries, the Plasma platform plugin will load this style
 * instead of breeze as default style when on a mobile platform.
 */

/*
 * Import the main breeze style first.
 */
@import "../breeze/style.css";

/*
 * Mobile-specific overrides.
 */
@import "overrides.css";
