/*
    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
    SPDX-FileCopyrightText: 2025 Arjen Hiemstra <ahiemstra@heimr.nl>

    This file is automatically generated from properties.css.j2.
    To regenerate, run `tools/propertygenerator/generate_properties.py`.
*/




@property layout-alignment-container {
    syntax: "item | content | background";
}

@property layout-alignment-horizontal {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property layout-alignment-vertical {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property layout-alignment-order {
    syntax: "<integer>";
}


@property width {
    syntax: "<length>";
}

@property height {
    syntax: "<length>";
}

@property spacing {
    syntax: "<length>";
}

@property padding-left {
    syntax: "<length>";
}

@property padding-right {
    syntax: "<length>";
}

@property padding-top {
    syntax: "<length>";
}

@property padding-bottom {
    syntax: "<length>";
}


@property inset-left {
    syntax: "<length>";
}

@property inset-right {
    syntax: "<length>";
}

@property inset-top {
    syntax: "<length>";
}

@property inset-bottom {
    syntax: "<length>";
}


@property margin-left {
    syntax: "<length>";
}

@property margin-right {
    syntax: "<length>";
}

@property margin-top {
    syntax: "<length>";
}

@property margin-bottom {
    syntax: "<length>";
}



@property text-alignment-container {
    syntax: "item | content | background";
}

@property text-alignment-horizontal {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property text-alignment-vertical {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property text-alignment-order {
    syntax: "<integer>";
}


@property font-family {
    syntax: "<string>";
}

@property text-color {
    syntax: "<color>";
}

@property text-wrap-mode {
    syntax: "no-wrap | word-wrap | manual-wrap | wrap-anywhere | wrap-at-word-boundary-or-anywhere | wrap";
}

@property text-elide {
    syntax: "none | left | middle | right";
}


@property icon-alignment-container {
    syntax: "item | content | background";
}

@property icon-alignment-horizontal {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property icon-alignment-vertical {
    syntax: "start | center | end | fill | stack-center | stack-fill";
}

@property icon-alignment-order {
    syntax: "<integer>";
}


@property icon-width {
    syntax: "<length>";
}

@property icon-height {
    syntax: "<length>";
}

@property icon-name {
    syntax: "<string>";
}

@property icon-source {
    syntax: "<url>";
}

@property icon-color {
    syntax: "<color>";
}


@property background-color {
    syntax: "<color>";
}

@property background-image-width {
    syntax: "<length>";
}

@property background-image-height {
    syntax: "<length>";
}

@property background-image-x-offset {
    syntax: "<length>";
}

@property background-image-y-offset {
    syntax: "<length>";
}

@property background-image-mask-color {
    syntax: "<color>";
}



@property border-left-width {
    syntax: "<length>";
}

@property border-left-color {
    syntax: "<color>";
}

@property border-left-image-width {
    syntax: "<length>";
}

@property border-left-image-height {
    syntax: "<length>";
}

@property border-left-image-x-offset {
    syntax: "<length>";
}

@property border-left-image-y-offset {
    syntax: "<length>";
}

@property border-left-image-mask-color {
    syntax: "<color>";
}



@property border-right-width {
    syntax: "<length>";
}

@property border-right-color {
    syntax: "<color>";
}

@property border-right-image-width {
    syntax: "<length>";
}

@property border-right-image-height {
    syntax: "<length>";
}

@property border-right-image-x-offset {
    syntax: "<length>";
}

@property border-right-image-y-offset {
    syntax: "<length>";
}

@property border-right-image-mask-color {
    syntax: "<color>";
}



@property border-top-width {
    syntax: "<length>";
}

@property border-top-color {
    syntax: "<color>";
}

@property border-top-image-width {
    syntax: "<length>";
}

@property border-top-image-height {
    syntax: "<length>";
}

@property border-top-image-x-offset {
    syntax: "<length>";
}

@property border-top-image-y-offset {
    syntax: "<length>";
}

@property border-top-image-mask-color {
    syntax: "<color>";
}



@property border-bottom-width {
    syntax: "<length>";
}

@property border-bottom-color {
    syntax: "<color>";
}

@property border-bottom-image-width {
    syntax: "<length>";
}

@property border-bottom-image-height {
    syntax: "<length>";
}

@property border-bottom-image-x-offset {
    syntax: "<length>";
}

@property border-bottom-image-y-offset {
    syntax: "<length>";
}

@property border-bottom-image-mask-color {
    syntax: "<color>";
}




@property outline-left-size {
    syntax: "<length>";
}

@property outline-left-color {
    syntax: "<color>";
}

@property outline-left-image-width {
    syntax: "<length>";
}

@property outline-left-image-height {
    syntax: "<length>";
}

@property outline-left-image-x-offset {
    syntax: "<length>";
}

@property outline-left-image-y-offset {
    syntax: "<length>";
}

@property outline-left-image-mask-color {
    syntax: "<color>";
}



@property outline-right-size {
    syntax: "<length>";
}

@property outline-right-color {
    syntax: "<color>";
}

@property outline-right-image-width {
    syntax: "<length>";
}

@property outline-right-image-height {
    syntax: "<length>";
}

@property outline-right-image-x-offset {
    syntax: "<length>";
}

@property outline-right-image-y-offset {
    syntax: "<length>";
}

@property outline-right-image-mask-color {
    syntax: "<color>";
}



@property outline-top-size {
    syntax: "<length>";
}

@property outline-top-color {
    syntax: "<color>";
}

@property outline-top-image-width {
    syntax: "<length>";
}

@property outline-top-image-height {
    syntax: "<length>";
}

@property outline-top-image-x-offset {
    syntax: "<length>";
}

@property outline-top-image-y-offset {
    syntax: "<length>";
}

@property outline-top-image-mask-color {
    syntax: "<color>";
}



@property outline-bottom-size {
    syntax: "<length>";
}

@property outline-bottom-color {
    syntax: "<color>";
}

@property outline-bottom-image-width {
    syntax: "<length>";
}

@property outline-bottom-image-height {
    syntax: "<length>";
}

@property outline-bottom-image-x-offset {
    syntax: "<length>";
}

@property outline-bottom-image-y-offset {
    syntax: "<length>";
}

@property outline-bottom-image-mask-color {
    syntax: "<color>";
}




@property border-top-left-radius {
    syntax: "<length>";
}

@property corners-top-left-width {
    syntax: "<length>";
}

@property corners-top-left-height {
    syntax: "<length>";
}

@property corners-top-left-color {
    syntax: "<color>";
}

@property corners-top-left-image-width {
    syntax: "<length>";
}

@property corners-top-left-image-height {
    syntax: "<length>";
}

@property corners-top-left-image-x-offset {
    syntax: "<length>";
}

@property corners-top-left-image-y-offset {
    syntax: "<length>";
}

@property corners-top-left-image-mask-color {
    syntax: "<color>";
}



@property border-top-right-radius {
    syntax: "<length>";
}

@property corners-top-right-width {
    syntax: "<length>";
}

@property corners-top-right-height {
    syntax: "<length>";
}

@property corners-top-right-color {
    syntax: "<color>";
}

@property corners-top-right-image-width {
    syntax: "<length>";
}

@property corners-top-right-image-height {
    syntax: "<length>";
}

@property corners-top-right-image-x-offset {
    syntax: "<length>";
}

@property corners-top-right-image-y-offset {
    syntax: "<length>";
}

@property corners-top-right-image-mask-color {
    syntax: "<color>";
}



@property border-bottom-left-radius {
    syntax: "<length>";
}

@property corners-bottom-left-width {
    syntax: "<length>";
}

@property corners-bottom-left-height {
    syntax: "<length>";
}

@property corners-bottom-left-color {
    syntax: "<color>";
}

@property corners-bottom-left-image-width {
    syntax: "<length>";
}

@property corners-bottom-left-image-height {
    syntax: "<length>";
}

@property corners-bottom-left-image-x-offset {
    syntax: "<length>";
}

@property corners-bottom-left-image-y-offset {
    syntax: "<length>";
}

@property corners-bottom-left-image-mask-color {
    syntax: "<color>";
}



@property border-bottom-right-radius {
    syntax: "<length>";
}

@property corners-bottom-right-width {
    syntax: "<length>";
}

@property corners-bottom-right-height {
    syntax: "<length>";
}

@property corners-bottom-right-color {
    syntax: "<color>";
}

@property corners-bottom-right-image-width {
    syntax: "<length>";
}

@property corners-bottom-right-image-height {
    syntax: "<length>";
}

@property corners-bottom-right-image-x-offset {
    syntax: "<length>";
}

@property corners-bottom-right-image-y-offset {
    syntax: "<length>";
}

@property corners-bottom-right-image-mask-color {
    syntax: "<color>";
}




@property shadow-offset-horizontal {
    syntax: "<length>";
}

@property shadow-offset-vertical {
    syntax: "<length>";
}


@property shadow-color {
    syntax: "<color>";
}

@property shadow-size {
    syntax: "<length>";
}

@property shadow-blur {
    syntax: "<length>";
}

@property shadow-left-size {
    syntax: "<length>";
}

@property shadow-left-color {
    syntax: "<color>";
}

@property shadow-left-image-width {
    syntax: "<length>";
}

@property shadow-left-image-height {
    syntax: "<length>";
}

@property shadow-left-image-x-offset {
    syntax: "<length>";
}

@property shadow-left-image-y-offset {
    syntax: "<length>";
}

@property shadow-left-image-mask-color {
    syntax: "<color>";
}



@property shadow-right-size {
    syntax: "<length>";
}

@property shadow-right-color {
    syntax: "<color>";
}

@property shadow-right-image-width {
    syntax: "<length>";
}

@property shadow-right-image-height {
    syntax: "<length>";
}

@property shadow-right-image-x-offset {
    syntax: "<length>";
}

@property shadow-right-image-y-offset {
    syntax: "<length>";
}

@property shadow-right-image-mask-color {
    syntax: "<color>";
}



@property shadow-top-size {
    syntax: "<length>";
}

@property shadow-top-color {
    syntax: "<color>";
}

@property shadow-top-image-width {
    syntax: "<length>";
}

@property shadow-top-image-height {
    syntax: "<length>";
}

@property shadow-top-image-x-offset {
    syntax: "<length>";
}

@property shadow-top-image-y-offset {
    syntax: "<length>";
}

@property shadow-top-image-mask-color {
    syntax: "<color>";
}



@property shadow-bottom-size {
    syntax: "<length>";
}

@property shadow-bottom-color {
    syntax: "<color>";
}

@property shadow-bottom-image-width {
    syntax: "<length>";
}

@property shadow-bottom-image-height {
    syntax: "<length>";
}

@property shadow-bottom-image-x-offset {
    syntax: "<length>";
}

@property shadow-bottom-image-y-offset {
    syntax: "<length>";
}

@property shadow-bottom-image-mask-color {
    syntax: "<color>";
}



@property shadow-top-left-radius {
    syntax: "<length>";
}

@property shadow-top-left-width {
    syntax: "<length>";
}

@property shadow-top-left-height {
    syntax: "<length>";
}

@property shadow-top-left-color {
    syntax: "<color>";
}

@property shadow-top-left-image-width {
    syntax: "<length>";
}

@property shadow-top-left-image-height {
    syntax: "<length>";
}

@property shadow-top-left-image-x-offset {
    syntax: "<length>";
}

@property shadow-top-left-image-y-offset {
    syntax: "<length>";
}

@property shadow-top-left-image-mask-color {
    syntax: "<color>";
}



@property shadow-top-right-radius {
    syntax: "<length>";
}

@property shadow-top-right-width {
    syntax: "<length>";
}

@property shadow-top-right-height {
    syntax: "<length>";
}

@property shadow-top-right-color {
    syntax: "<color>";
}

@property shadow-top-right-image-width {
    syntax: "<length>";
}

@property shadow-top-right-image-height {
    syntax: "<length>";
}

@property shadow-top-right-image-x-offset {
    syntax: "<length>";
}

@property shadow-top-right-image-y-offset {
    syntax: "<length>";
}

@property shadow-top-right-image-mask-color {
    syntax: "<color>";
}



@property shadow-bottom-left-radius {
    syntax: "<length>";
}

@property shadow-bottom-left-width {
    syntax: "<length>";
}

@property shadow-bottom-left-height {
    syntax: "<length>";
}

@property shadow-bottom-left-color {
    syntax: "<color>";
}

@property shadow-bottom-left-image-width {
    syntax: "<length>";
}

@property shadow-bottom-left-image-height {
    syntax: "<length>";
}

@property shadow-bottom-left-image-x-offset {
    syntax: "<length>";
}

@property shadow-bottom-left-image-y-offset {
    syntax: "<length>";
}

@property shadow-bottom-left-image-mask-color {
    syntax: "<color>";
}



@property shadow-bottom-right-radius {
    syntax: "<length>";
}

@property shadow-bottom-right-width {
    syntax: "<length>";
}

@property shadow-bottom-right-height {
    syntax: "<length>";
}

@property shadow-bottom-right-color {
    syntax: "<color>";
}

@property shadow-bottom-right-image-width {
    syntax: "<length>";
}

@property shadow-bottom-right-image-height {
    syntax: "<length>";
}

@property shadow-bottom-right-image-x-offset {
    syntax: "<length>";
}

@property shadow-bottom-right-image-y-offset {
    syntax: "<length>";
}

@property shadow-bottom-right-image-mask-color {
    syntax: "<color>";
}





