/*
 * SPDX-License-Identifier: BSD-2-Clause
 * SPDX-FileCopyrightText: 2026 Arjen Hiemstra <ahiemstra@heimr.nl>
 */

menuitem > arrow
{
    icon-name: "arrow-left-symbolic"
}

scrollview.vertical-scroll
{
    padding-right: 0px;
    padding-left: var(--scrollbar-size);
}

scrollbar.vertical
{
    border-left: none;
    border-right: 1px solid var(--bar-active-border-color);
}
