/*
 * SPDX-License-Identifier: BSD-2-Clause
 * SPDX-FileCopyrightText: 2025 Arjen Hiemstra <ahiemstra@heimr.nl>
 */

/*
 * Global defaults that should apply to all elements.
 */

* {
    icon-size: var(--icon-size-small);
}
